eeve
====

.. image:: https://img.shields.io/pypi/v/eeve.svg
    :target: https://pypi.python.org/pypi/eeve
    :alt: Latest PyPI version

.. image::  https://travis-ci.org/vMarcelino/eeve.svg?branch=master
   :target:  https://travis-ci.org/vMarcelino/eeve
   :alt: Latest Travis CI build status

A simple, flexible and powerfull event trigger

Usage
-----
:code:`python -m eeve`

Or from the project folder:

:code:`python run.py`

Installation
------------
From pip:

:code:`pip install -U eeve`

From source:

:code:`pip install -e .` or :code:`python setup.py install`

Requirements
^^^^^^^^^^^^

Compatibility
-------------

Only tested on windows x64, but should work on any other OS just fine. Actions and triggers, however, have their own compatibility


Licence
-------
MIT Licence

Authors
-------

`eeve` was written by `Victor Marcelino <victor.fmarcelino@gmail.com>`_.
